###################################################
### chunk number 1: 
###################################################
library(lattice)
library(xtable)
library(randomLCA)
data(dentistry)
options(width=60)


###################################################
### chunk number 2: 
###################################################
myocardial.lca1 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=1)
myocardial.lca2 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=2,calcSE=TRUE)
myocardial.lca3 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=3)


###################################################
### chunk number 3: 
###################################################
bic.data <- data.frame(classes=1:3,bic=c(BIC(myocardial.lca1),
	BIC(myocardial.lca2),BIC(myocardial.lca3)))


###################################################
### chunk number 4: 
###################################################
print(xtable(bic.data, digits = c(0,0,1),caption="BIC by class.",
	label="tab:bic1"),include.rownames=FALSE)


###################################################
### chunk number 5: 
###################################################
summary(myocardial.lca2)


###################################################
### chunk number 6: 
###################################################
outcomep.data <- summary(myocardial.lca2)$outcomep


###################################################
### chunk number 7: 
###################################################
print(xtable(outcomep.data, digits = c(0,3,3,3,3),caption="Outcome Probabilities.",
	label="tab:outcomep1"))


###################################################
### chunk number 8: 
###################################################
classprobs <- cbind(myocardial.lca2$patterns,myocardial.lca2$classprob)
colnames(classprobs) <- c(names(myocardial)[1:4],"Class 1","Class 2")


###################################################
### chunk number 9: 
###################################################
print(xtable(classprobs, digits = c(0,0,0,0,0,3,3),caption="Class Probabilities.",
	label="tab:classprob1"),include.rownames=FALSE)


###################################################
### chunk number 10: 
###################################################
trellis.par.set(col.whitebg())
print(plot(myocardial.lca2,type="l",xlab="Test",ylab="Outcome Probability",
	scales=list(x=list(at=1:4,labels=names(myocardial)[1:4]))))


###################################################
### chunk number 11: 
###################################################
dentistry.lca1 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=1)
dentistry.lca2 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=2,calcSE=TRUE)
dentistry.lca3 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=3)
dentistry.lca4 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=4)


###################################################
### chunk number 12: 
###################################################
bic.data <- data.frame(classes=1:4,bic=c(BIC(dentistry.lca1),
	BIC(dentistry.lca2),BIC(dentistry.lca3),BIC(dentistry.lca4)))


###################################################
### chunk number 13: 
###################################################
print(xtable(bic.data, digits = c(0,0,1),caption="BIC by class.",
	label="tab:bic"),include.rownames=FALSE)


###################################################
### chunk number 14: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca3,type="l",xlab="Dentist",ylab="Outcome Probability"))


###################################################
### chunk number 15: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca2,type="l",xlab="Dentist",ylab="Outcome Probability"))


###################################################
### chunk number 16: 
###################################################
outcome.probs(dentistry.lca2)


###################################################
### chunk number 17: 
###################################################
probs <- outcome.probs(dentistry.lca2)
probs <- data.frame(tpr=probs[[2]][,1],fpr=probs[[1]][,1])


###################################################
### chunk number 18: 
###################################################
trellis.par.set(col.whitebg())
print(plot(tpr~fpr,type="p",xlab="False Positive Rate\n(1-Specificity)",ylab="True Positive Rate (Sensitivity)",data=probs))


###################################################
### chunk number 19: 
###################################################
dentistry.lca2random <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2,nclass=2,random=TRUE,probit=TRUE)


###################################################
### chunk number 20: 
###################################################
dentistry.lca2random1 <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2random,nclass=2,random=TRUE,probit=TRUE,blocksize=5)


###################################################
### chunk number 21: 
###################################################
dentistry.lca2random2 <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2random1,nclass=2,random=TRUE,probit=TRUE,
	blocksize=5,byclass=TRUE,quadpoints=41)


###################################################
### chunk number 22: 
###################################################
obs.data <- data.frame(dentistry.lca2random1$patterns,dentistry.lca2random1$observed,
	dentistry.lca2$fitted,dentistry.lca2random1$fitted)
names(obs.data) <- c("V1","V2","V3","V4","V5","Obs","Exp 2LC","Exp 2LCR")


###################################################
### chunk number 23: 
###################################################
print(xtable(obs.data, caption="Observed and expected frequencies",
	digits = c(0,rep(0,5),0,1,1),label="tab:obs"),include.rownames=FALSE)


###################################################
### chunk number 24: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca2random1,graphtype="marginal",type="l",xlab="Dentist",ylab="Marginal Outcome Probability"))


